@@ -33,7 +33,7 @@ PYPI_WHEEL_URI_RE = re.compile(
     re.escape(PYPI_URI_PREFIX) + r"(?P<pytag>[^/]+)/[^/]/(?P<package>[^/]+)/"
     r"(?P<fn_package>[^/-]+)-(?P<version>[^/-]+)-(?P=pytag)-(?P<abitag>[^/]+)\.whl$"
 )
-USE_FLAGS_PYTHON_USEDEP = re.compile(r"\[(.+,)?\$\{PYTHON_USEDEP\}(,.+)?\]$")
+USE_FLAGS_PYTHON_USEDEP = re.compile(r"\[(.+,)?\$\{PYTHON_(SINGLE_)?USEDEP\}(,.+)?\]$")
 
 PROJECT_SYMBOL_NORMALIZE_RE = re.compile(r"[-_.]+")
 
@@ -168,20 +168,18 @@ class PythonHasVersionUsage(results.LinesResult, results.Style):
 
 class PythonHasVersionMissingPythonUseDep(results.LineResult, results.Error):
     """Package calls ``python_has_version`` or ``has_version`` without
-    ``[${PYTHON_USEDEP}]`` suffix.
+    ``[${PYTHON_USEDEP}]`` or ``[${PYTHON_SINGLE_USEDEP}]`` suffix.
 
     All calls  to ``python_has_version`` or ``has_version`` inside
-    ``python_check_deps`` should contain ``[${PYTHON_USEDEP}]`` suffix for the
-    dependency argument [#]_.
+    ``python_check_deps`` should contain ``[${PYTHON_USEDEP}]`` or ``[${PYTHON_SINGLE_USEDEP}]``
+    suffix for the dependency argument [#]_.
 
     .. [#] https://projects.gentoo.org/python/guide/any.html#dependencies
     """
 
     @property
     def desc(self):
-        return (
-            f"line: {self.lineno}: missing [${{PYTHON_USEDEP}}] suffix for argument {self.line!r}"
-        )
+        return f"line: {self.lineno}: missing [${{PYTHON_USEDEP}}] or [${{PYTHON_SINGLE_USEDEP}}] suffix for argument {self.line!r}"
 
 
 class PythonAnyMismatchedUseHasVersionCheck(results.VersionResult, results.Warning):
@@ -247,6 +245,40 @@ class PythonMissingSCMDependency(results.VersionResult, results.Warning):
     )
 
 
+class MisplacedEPyTestVar(results.LineResult, results.Error):
+    """Invalid placement of ``EPYTEST_*`` variable
+
+    ``EPYTEST_*`` variables need to be set prior to ``distutils_enable_tests``
+    to enable its functionality.  The exception to that rule are local overrides
+    in ``python_test()`` -- we presume the author knows what they're doing.
+    """
+
+    def __init__(self, variable, **kwargs):
+        super().__init__(**kwargs)
+        self.variable = variable
+
+    @property
+    def desc(self):
+        return (
+            f"line {self.lineno}: variable set after calling distutils_enable_tests: {self.line!r}"
+        )
+
+
+class ShadowedEPyTestTimeout(results.LineResult, results.Warning):
+    """``EPYTEST_TIMEOUT`` shadows user-specified value
+
+    ``EPYTEST_TIMEOUT`` should be set via ``${EPYTEST_TIMEOUT:=...}`` to permit
+    using an environment variable to override it.
+    """
+
+    @property
+    def desc(self):
+        return (
+            f"line {self.lineno}: EPYTEST_TIMEOUT shadows user value, use "
+            f"${{EPYTEST_TIMEOUT:=...}} instead: {self.line!r}"
+        )
+
+
 class PythonCheck(Check):
     """Python eclass checks.
 
@@ -256,7 +288,7 @@ class PythonCheck(Check):
 
     _source = sources.EbuildParseRepoSource
     known_results = frozenset(
-        [
+        {
             MissingPythonEclass,
             PythonMissingRequiredUse,
             PythonMissingDeps,
@@ -268,7 +300,9 @@ class PythonCheck(Check):
             PythonAnyMismatchedUseHasVersionCheck,
             PythonAnyMismatchedDepHasVersionCheck,
             PythonMissingSCMDependency,
-        ]
+            MisplacedEPyTestVar,
+            ShadowedEPyTestTimeout,
+        }
     )
 
     has_version_known_flags = {
@@ -389,6 +423,62 @@ class PythonCheck(Check):
             if not self.setuptools_scm.intersection(bdepends):
                 yield PythonMissingSCMDependency(pkg=pkg)
 
+    def _get_all_global_assignments(self, pkg):
+        """Iterate over global plain and expansion assignments"""
+        for node in pkg.global_query(bash.var_assign_query):
+            name = pkg.node_str(node.child_by_field_name("name"))
+            yield (name, node)
+
+        # ${var:=value} expansions.
+        for node in pkg.global_query(bash.var_expansion_query):
+            if node.children[0].text != b"${":
+                continue
+            name = node.children[1].text
+            if node.children[2].text not in (b"=", b":="):
+                continue
+            yield (name.decode(), node)
+
+    def check_epytest_vars(self, pkg):
+        """Check for incorrect use of EPYTEST_* variables"""
+        # TODO: do we want to check for multiple det calls? Quite unlikely.
+        det_lineno = None
+        for node in pkg.global_query(bash.cmd_query):
+            name = pkg.node_str(node.child_by_field_name("name"))
+            if name != "distutils_enable_tests":
+                continue
+            for argument_node in node.children_by_field_name("argument"):
+                argument = pkg.node_str(argument_node)
+                # Check if the first argument is "pytest", but we need
+                # to skip line continuations explicitly.
+                if argument == "pytest":
+                    det_lineno, _ = node.start_point
+                    break
+                elif argument != "\\":
+                    return
+
+        if det_lineno is None:
+            return
+
+        for var_name, var_node in self._get_all_global_assignments(pkg):
+            # While not all variables affect distutils_enable_tests, make it
+            # future proof.  Also, it makes sense to keep them together.
+            # Just opt out from the long lists.
+            if var_name.startswith("EPYTEST_") and var_name not in (
+                "EPYTEST_DESELECT",
+                "EPYTEST_IGNORE",
+            ):
+                lineno, _ = var_node.start_point
+                if lineno > det_lineno:
+                    line = pkg.node_str(var_node)
+                    yield MisplacedEPyTestVar(var_name, line=line, lineno=lineno + 1, pkg=pkg)
+
+        for var_node in bash.var_assign_query.captures(pkg.tree.root_node).get("assign", ()):
+            var_name = pkg.node_str(var_node.child_by_field_name("name"))
+            if var_name == "EPYTEST_TIMEOUT":
+                lineno, _ = var_node.start_point
+                line = pkg.node_str(var_node)
+                yield ShadowedEPyTestTimeout(line=line, lineno=lineno + 1, pkg=pkg)
+
     @staticmethod
     def _prepare_deps(deps: str):
         try:
@@ -545,6 +635,7 @@ class PythonCheck(Check):
 
         if "distutils-r1" in pkg.inherited:
             yield from self.check_pep517(pkg)
+            yield from self.check_epytest_vars(pkg)
 
         any_dep_func = self.eclass_any_dep_func[eclass]
         python_check_deps = self.build_python_gen_any_dep_calls(pkg, any_dep_func)
